==> v4_navigation_engine-0.1.62.tar.gz: ios/Classes/NavigationV4 (1)/Navigation/View/CustomVoiceController.swift <==
//
//  CustomVoiceController.swift
//  MyThalassa
//
//  Created by hassine othmane on 9/24/19.
//  Copyright © 2019 mile. All rights reserved.
//

import UIKit
import MapboxSpeech
import Mapbox
import AVFoundation
import MapboxSpeech
import MapboxCoreNavigation
import MapboxDirections
import MapboxNavigation




/// MapboxVoiceController 82

//@objc public func audioPlayerDidFinishPlaying(_ player: AVAudioPlayer, successfully flag: Bool) {
//    do {
//        try unDuckAudio()
//         NotificationCenter.default.post(name:NSNotification.Name("finishAudio"),object: nil)
//        print("finishAudio")
//    } catch {
//        voiceControllerDelegate?.voiceController?(self, spokenInstructionsDidFailWith: error)
//    }
//
//}

class CustomVoiceController: MapboxSpeechSynthesizer {



    @objc func playerDidFinishPlaying() {

        //initTimerSmartFact()
        NotificationCenter.default.post(name:NSNotification.Name("initTimerSmartFact"),object: nil)
        if let player = self.audioPlayer
        {
            if !player.isPlaying
            {
                if (PlayerManager.shared.speechSynthesizer.isPaused)   && PlayerManager.shared.arrayStringPOIQueue.count > 0
                {
                    PlayerManager.shared.continueSpeaking()

                }
            }
        }
    }

    func initNotification()
    {
        NotificationCenter.default.addObserver(self,selector: #selector(playerDidFinishPlaying),name: NSNotification.Name ("finishAudio"),object: nil)
    }

    func playDirectionnal(instruction: SpokenInstruction, data: Data) -> Void {
        guard !NavigationSettings.shared.voiceMuted else { return }
        if (  PlayerManager.shared.speechSynthesizer.isSpeaking )
        {
           // PlayerManager.shared.speechSynthesizer.pauseSpeaking(at: AVSpeechBoundary.immediate)
        }
       // super.play(data)
        super.speak(instruction, data: data)
    }

    func stopPlayer() -> Void
    {
        self.audioPlayer?.stop()
    }

    override func speak(_ instruction: SpokenInstruction, data: Data) {


        if (MyNavigationView.mutedZone == false)
        {

            if !instruction.text.contains("your 1st destination") &&
                !instruction.text.contains("votre première destination") &&
                !instruction.text.contains("vous arriverez à votre première destination") && !instruction.text.contains("as a llegar a tu 1ª destino ")  && !instruction.text.contains("1ª destinazione") && !instruction.text.contains("poi sei arrivato alla tua 1ª destinazione") && !instruction.text.contains(" 1º destino") && !instruction.text.contains("erstes Ziel erreicht") && !instruction.text.contains("erstes Ziel") && instruction.distanceAlongStep < 90


            {
                print("inst2 = \(instruction.distanceAlongStep)  \(instruction.text)")
                  if (  PlayerManager.shared.speechSynthesizer.isSpeaking )
                          {

                             PlayerManager.shared.speechSynthesizer.pauseSpeaking(at: AVSpeechBoundary.immediate)
                    super.speak(instruction, data: data)

                    //    PlayerManager.shared.pausePlayerDirectional()
                          }
                else
                  {
                    super.speak(instruction, data: data)
                }

            }
            else
            {
                print("inst = \(instruction.text)")
            }

        }
        else
        {
            print("muted zone")
        }
    }

/*


//    override func didPassSpokenInstructionPoint(notification: NSNotification) {
//        print(notification)
//        super.didPassSpokenInstructionPoint(notification: notification)
//        let routeProgress = notification.userInfo![RouteControllerNotificationUserInfoKey.routeProgressKey] as! RouteProgress
//        print(routeProgress.currentLegProgress.currentStep.maneuverType)
//        //        let soundForInstruction = audio(for: routeProgress.currentLegProgress.currentStep)
//        let instruction = notification.userInfo![RouteControllerNotificationUserInfoKey.spokenInstructionKey] as! SpokenInstruction
//        //        play(instruction: instruction, data: soundForInstruction)
//
//        if routeProgress.currentLegProgress.currentStep.maneuverType == .depart
//        {
//            if  let steps = routeProgress.currentLegProgress.currentStep.instructionsSpokenAlongStep
//            {
//                if steps.count > 1
//                {
//                    //  play(instruction: instruction, data: soundForInstruction)
//                }
//            }
//        }
//
//    }

    


    override func speakWithDefaultSpeechSynthesizer(_ instruction: SpokenInstruction, error: MapboxNavigation.SpeechError?) {
        print("instruction \(instruction)")

        if (MyNavigationView.mutedZone == false)
        {

            if !instruction.text.contains("you will arrive at your 1st destination") && !instruction.text.contains("vous arriverez à votre première destination") && !instruction.text.contains("as a llegar a tu 1ª destino ")  && !instruction.text.contains("poi sei arrivato alla tua 1ª destinazione") && !instruction.text.contains("poi sei arrivato alla tua 1ª destinazione") && !instruction.text.contains("está a chegar ao seu 1º destino") && !instruction.text.contains("erstes Ziel erreicht") && !instruction.text.contains("erstes Ziel")


            {
                  if (  PlayerManager.shared.speechSynthesizer.isSpeaking )
                          {
                              print("speak 2  = \(instruction.text)")
                             PlayerManager.shared.speechSynthesizer.pauseSpeaking(at: AVSpeechBoundary.immediate)
                                                     //     super.speakWithDefaultSpeechSynthesizer(instruction, error: error)
                    PlayerManager.shared.playSyntDirectionnal(description: instruction.text)

                              //    PlayerManager.shared.pausePlayerDirectional()
                          }
                else
                  {
                    //super.speakWithDefaultSpeechSynthesizer(instruction, error: error)
                    PlayerManager.shared.playSyntDirectionnal(description: instruction.text)
                }

            }
            else
            {
                print(instruction.text)
            }

        }
        else
        {
            print("muted zone")
        }

    }


    override func speak(_ instruction: SpokenInstruction) {
        print("instruction \(instruction)")
        super.speak(instruction)
    }

    func initNotification()
    {
        NotificationCenter.default.addObserver(self,selector: #selector(playerDidFinishPlaying),name: NSNotification.Name ("finishAudio"),object: nil)
    }

    func playDirectionnal(instruction: SpokenInstruction, data: Data) -> Void {
        guard !NavigationSettings.shared.voiceMuted else { return }
        if (  PlayerManager.shared.speechSynthesizer.isSpeaking )
        {
           // PlayerManager.shared.speechSynthesizer.pauseSpeaking(at: AVSpeechBoundary.immediate)
        }
       // super.play(data)
        super.play(instruction: instruction, data: data)
    }

    func stopPlayer() -> Void
    {
        self.audioPlayer?.stop()
    }


    override func play(instruction: SpokenInstruction, data: Data) {

        print("instruction \(instruction)")

        if (MyNavigationView.mutedZone == false)
        {

            if !instruction.text.contains("you will arrive at your 1st destination") && !instruction.text.contains("vous arriverez à votre première destination") && !instruction.text.contains("as a llegar a tu 1ª destino ")  && !instruction.text.contains("poi sei arrivato alla tua 1ª destinazione") && !instruction.text.contains("poi sei arrivato alla tua 1ª destinazione") && !instruction.text.contains("está a chegar ao seu 1º destino") && !instruction.text.contains("erstes Ziel erreicht") && !instruction.text.contains("erstes Ziel")


            {
                  if (  PlayerManager.shared.speechSynthesizer.isSpeaking )
                          {
                              print("speak 2  = \(instruction.text)")
                             PlayerManager.shared.speechSynthesizer.pauseSpeaking(at: AVSpeechBoundary.immediate)
                                                          super.play(instruction: instruction, data: data)

                              //    PlayerManager.shared.pausePlayerDirectional()
                          }
                else
                  {
                     super.play(instruction: instruction, data: data)
                }

            }
            else
            {
                print(instruction.text)
            }

        }
        else
        {
            print("muted zone")
        }
    }


    @objc func playerDidFinishPlaying() {

        //initTimerSmartFact()
        NotificationCenter.default.post(name:NSNotification.Name("initTimerSmartFact"),object: nil)
        if let player = self.audioPlayer
        {
            if !player.isPlaying
            {
                if (PlayerManager.shared.speechSynthesizer.isPaused)   && PlayerManager.shared.arrayStringPOIQueue.count > 0
                {
                    PlayerManager.shared.continueSpeaking()

                }
            }
        }
    }


    override func audioPlayerDidFinishPlaying(_ player: AVAudioPlayer, successfully flag: Bool) {
        super.audioPlayerDidFinishPlaying(player, successfully: flag)
         NotificationCenter.default.post(name:NSNotification.Name("finishAudio"),object: nil)
    }


    */

    

    override func audioPlayerDidFinishPlaying(_ player: AVAudioPlayer, successfully flag: Bool) {
        super.audioPlayerDidFinishPlaying(player, successfully: flag)
         NotificationCenter.default.post(name:NSNotification.Name("finishAudio"),object: nil)
    }


}

==> v4_navigation_engine-0.1.80.tar.gz: ios/Classes/NavigationV4 (1)/Navigation/View/CustomVoiceController.swift <==
//
//  CustomVoiceController.swift
//  MyThalassa
//
//  Created by hassine othmane on 9/24/19.
//  Copyright © 2019 mile. All rights reserved.
//

import UIKit
import MapboxSpeech
import Mapbox
import AVFoundation
import MapboxSpeech
import MapboxCoreNavigation
import MapboxDirections
import MapboxNavigation




/// MapboxVoiceController 82

//@objc public func audioPlayerDidFinishPlaying(_ player: AVAudioPlayer, successfully flag: Bool) {
//    do {
//        try unDuckAudio()
//         NotificationCenter.default.post(name:NSNotification.Name("finishAudio"),object: nil)
//        print("finishAudio")
//    } catch {
//        voiceControllerDelegate?.voiceController?(self, spokenInstructionsDidFailWith: error)
//    }
//
//}

class CustomVoiceController: MapboxSpeechSynthesizer {

    public var navigationView: MyNavigationView? = nil

    override func audioPlayerDidFinishPlaying(_ player: AVAudioPlayer, successfully flag: Bool) {
        super.audioPlayerDidFinishPlaying(player, successfully: flag)
        NotificationCenter.default.post(name:NSNotification.Name("finishAudio"),object: nil)
        navigationView?.flutterOnMapBoxSpeak(isReading: false)
    }

    @objc func playerDidFinishPlaying() {

        //initTimerSmartFact()
        NotificationCenter.default.post(name:NSNotification.Name("initTimerSmartFact"),object: nil)
        if let player = self.audioPlayer
        {
            if !player.isPlaying
            {
                if (PlayerManager.shared.speechSynthesizer.isPaused)   && PlayerManager.shared.arrayStringPOIQueue.count > 0
                {
                    PlayerManager.shared.continueSpeaking()

                }
            }
        }
    }

    func initNotification()
    {
        NotificationCenter.default.addObserver(self,selector: #selector(playerDidFinishPlaying),name: NSNotification.Name ("finishAudio"),object: nil)
    }

    func playDirectionnal(instruction: SpokenInstruction, data: Data) -> Void {
        guard !NavigationSettings.shared.voiceMuted else { return }
        if (  PlayerManager.shared.speechSynthesizer.isSpeaking )
        {
           // PlayerManager.shared.speechSynthesizer.pauseSpeaking(at: AVSpeechBoundary.immediate)
        }
       // super.play(data)
        super.speak(instruction, data: data)
    }

    func stopPlayer() -> Void
    {
        self.audioPlayer?.stop()
    }

    override func speak(_ instruction: SpokenInstruction, data: Data) {
        if (MyNavigationView.mutedZone == false) {
            if !instruction.text.contains("your 1st destination") &&
               !instruction.text.contains("votre première destination") &&
               !instruction.text.contains("vous arriverez à votre première destination") &&
               !instruction.text.contains("as a llegar a tu 1ª destino ")  &&
               !instruction.text.contains("1ª destinazione") &&
               !instruction.text.contains("poi sei arrivato alla tua 1ª destinazione") &&
               !instruction.text.contains(" 1º destino") &&
               !instruction.text.contains("erstes Ziel erreicht") &&
               !instruction.text.contains("erstes Ziel") &&
               instruction.distanceAlongStep < 90 {

                print("inst2 = \(instruction.distanceAlongStep)  \(instruction.text)")
                if(PlayerManager.shared.speechSynthesizer.isSpeaking) {
                    PlayerManager.shared.speechSynthesizer.pauseSpeaking(at: AVSpeechBoundary.immediate)
                    super.speak(instruction, data: data)
                    //PlayerManager.shared.pausePlayerDirectional()
               } else{
                    super.speak(instruction, data: data)
               }
            } else {
                print("inst = \(instruction.text)")
                navigationView?.flutterOnMapBoxSpeak(isReading: true)
            }
        } else {
            print("muted zone")
        }
    }

/*


//    override func didPassSpokenInstructionPoint(notification: NSNotification) {
//        print(notification)
//        super.didPassSpokenInstructionPoint(notification: notification)
//        let routeProgress = notification.userInfo![RouteControllerNotificationUserInfoKey.routeProgressKey] as! RouteProgress
//        print(routeProgress.currentLegProgress.currentStep.maneuverType)
//        //        let soundForInstruction = audio(for: routeProgress.currentLegProgress.currentStep)
//        let instruction = notification.userInfo![RouteControllerNotificationUserInfoKey.spokenInstructionKey] as! SpokenInstruction
//        //        play(instruction: instruction, data: soundForInstruction)
//
//        if routeProgress.currentLegProgress.currentStep.maneuverType == .depart
//        {
//            if  let steps = routeProgress.currentLegProgress.currentStep.instructionsSpokenAlongStep
//            {
//                if steps.count > 1
//                {
//                    //  play(instruction: instruction, data: soundForInstruction)
//                }
//            }
//        }
//
//    }

    


    override func speakWithDefaultSpeechSynthesizer(_ instruction: SpokenInstruction, error: MapboxNavigation.SpeechError?) {
        print("instruction \(instruction)")

        if (MyNavigationView.mutedZone == false)
        {

            if !instruction.text.contains("you will arrive at your 1st destination") && !instruction.text.contains("vous arriverez à votre première destination") && !instruction.text.contains("as a llegar a tu 1ª destino ")  && !instruction.text.contains("poi sei arrivato alla tua 1ª destinazione") && !instruction.text.contains("poi sei arrivato alla tua 1ª destinazione") && !instruction.text.contains("está a chegar ao seu 1º destino") && !instruction.text.contains("erstes Ziel erreicht") && !instruction.text.contains("erstes Ziel")


            {
                  if (  PlayerManager.shared.speechSynthesizer.isSpeaking )
                          {
                              print("speak 2  = \(instruction.text)")
                             PlayerManager.shared.speechSynthesizer.pauseSpeaking(at: AVSpeechBoundary.immediate)
                                                     //     super.speakWithDefaultSpeechSynthesizer(instruction, error: error)
                    PlayerManager.shared.playSyntDirectionnal(description: instruction.text)

                              //    PlayerManager.shared.pausePlayerDirectional()
                          }
                else
                  {
                    //super.speakWithDefaultSpeechSynthesizer(instruction, error: error)
                    PlayerManager.shared.playSyntDirectionnal(description: instruction.text)
                }

            }
            else
            {
                print(instruction.text)
            }

        }
        else
        {
            print("muted zone")
        }

    }


    override func speak(_ instruction: SpokenInstruction) {
        print("instruction \(instruction)")
        super.speak(instruction)
    }

    func initNotification()
    {
        NotificationCenter.default.addObserver(self,selector: #selector(playerDidFinishPlaying),name: NSNotification.Name ("finishAudio"),object: nil)
    }

    func playDirectionnal(instruction: SpokenInstruction, data: Data) -> Void {
        guard !NavigationSettings.shared.voiceMuted else { return }
        if (  PlayerManager.shared.speechSynthesizer.isSpeaking )
        {
           // PlayerManager.shared.speechSynthesizer.pauseSpeaking(at: AVSpeechBoundary.immediate)
        }
       // super.play(data)
        super.play(instruction: instruction, data: data)
    }

    func stopPlayer() -> Void
    {
        self.audioPlayer?.stop()
    }


    override func play(instruction: SpokenInstruction, data: Data) {

        print("instruction \(instruction)")

        if (MyNavigationView.mutedZone == false)
        {

            if !instruction.text.contains("you will arrive at your 1st destination") && !instruction.text.contains("vous arriverez à votre première destination") && !instruction.text.contains("as a llegar a tu 1ª destino ")  && !instruction.text.contains("poi sei arrivato alla tua 1ª destinazione") && !instruction.text.contains("poi sei arrivato alla tua 1ª destinazione") && !instruction.text.contains("está a chegar ao seu 1º destino") && !instruction.text.contains("erstes Ziel erreicht") && !instruction.text.contains("erstes Ziel")


            {
                  if (  PlayerManager.shared.speechSynthesizer.isSpeaking )
                          {
                              print("speak 2  = \(instruction.text)")
                             PlayerManager.shared.speechSynthesizer.pauseSpeaking(at: AVSpeechBoundary.immediate)
                                                          super.play(instruction: instruction, data: data)

                              //    PlayerManager.shared.pausePlayerDirectional()
                          }
                else
                  {
                     super.play(instruction: instruction, data: data)
                }

            }
            else
            {
                print(instruction.text)
            }

        }
        else
        {
            print("muted zone")
        }
    }


    @objc func playerDidFinishPlaying() {

        //initTimerSmartFact()
        NotificationCenter.default.post(name:NSNotification.Name("initTimerSmartFact"),object: nil)
        if let player = self.audioPlayer
        {
            if !player.isPlaying
            {
                if (PlayerManager.shared.speechSynthesizer.isPaused)   && PlayerManager.shared.arrayStringPOIQueue.count > 0
                {
                    PlayerManager.shared.continueSpeaking()

                }
            }
        }
    }


    override func audioPlayerDidFinishPlaying(_ player: AVAudioPlayer, successfully flag: Bool) {
        super.audioPlayerDidFinishPlaying(player, successfully: flag)
         NotificationCenter.default.post(name:NSNotification.Name("finishAudio"),object: nil)
    }


    */


}
